Module error

Module error 

Shared Tidecoin-node script error types and mappings.

Enums

NodeParityError
Error returned by the shared Tidecoin node parity harness.
ScriptError
Tidecoin-node script error codes exposed through the node parity bridge.