#[non_exhaustive]pub enum NodeParityError {
Environment(&'static str),
InvalidCString(&'static str),
BridgeFailure(&'static str),
Script(ScriptError),
}Expand description
Error returned by the shared Tidecoin node parity harness.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Environment(&'static str)
The configured Tidecoin node checkout is missing or malformed.
InvalidCString(&'static str)
A required C-string conversion failed.
BridgeFailure(&'static str)
A native bridge call returned an unexpected failure mode.
Script(ScriptError)
A Tidecoin-node script verification call returned a script error.